import React from 'react';
import { useAccount, useConnect, useDisconnect, Connector } from 'wagmi';
import { GetAccountResult } from '@wagmi/core';
import { providers } from 'ethers'


type ConnectEthWalletProps = {
  children(props: {
    connectors: Connector[],
    connect: (connector: Connector) => Promise<any>,
    disconnect: () => void,
    account?: GetAccountResult<providers.BaseProvider>,
  }): React.ReactElement,
};

const ConnectEthWallet: React.FC<ConnectEthWalletProps> = function ConnectEthWallet({ children }: ConnectEthWalletProps) {
  const { connectors, connectAsync } = useConnect();
  const { data: account } = useAccount();
  const { disconnect } = useDisconnect();

  return children({
    connectors,
    connect: (connector) => connectAsync(connector),
    disconnect: () => disconnect(),
    account
  });
};

export default ConnectEthWallet;
