import React from 'react';
import usePayInvoice from '../../hooks/usePayInvoice';

const DEFAULT_BUTTON_TAG = 'button';

type PayInvoiceButtonOwnProps<T extends React.ElementType = 'button'> = {
  as?: T;
  className?: string;
  invoice?: string;
};

type ButtonProps<T extends React.ElementType> = PayInvoiceButtonOwnProps<T> &
  Omit<React.ComponentPropsWithoutRef<T>, keyof PayInvoiceButtonOwnProps<T>>;

function PayInvoiceButton<T extends React.ElementType = typeof DEFAULT_BUTTON_TAG>({
  as,
  className,
  invoice,
  children,
  ...props
}: ButtonProps<T>): React.ReactElement | null {
  const Tag = as || DEFAULT_BUTTON_TAG;
  const { payInvoice, loading } = usePayInvoice()

  const handleClick = React.useCallback(() => {
    if (!payInvoice || !invoice) return;
    return payInvoice(invoice);
  }, [invoice, payInvoice]);

  return (
    <Tag
      disabled={!invoice || !payInvoice || loading}
      className={className}
      onClick={handleClick}
      {...props}
    >
      {children}
    </Tag>
  );
}

export type { PayInvoiceButtonOwnProps };

export default PayInvoiceButton;
