import usePayPaymentIntent from '../../hooks/usePayPaymentIntent';
import React from 'react';

const DEFAULT_BUTTON_TAG = 'button';

type PayPaymentIntentButtonOwnProps<T extends React.ElementType = 'button'> = {
  as?: T;
  className?: string;
  paymentIntent?: string;
};

type ButtonProps<T extends React.ElementType> = PayPaymentIntentButtonOwnProps<T> &
  Omit<React.ComponentPropsWithoutRef<T>, keyof PayPaymentIntentButtonOwnProps<T>>;

function PayPaymentIntentButton<T extends React.ElementType = typeof DEFAULT_BUTTON_TAG>({
  as,
  className,
  paymentIntent,
  children,
  ...props
}: ButtonProps<T>): React.ReactElement | null {
  const Tag = as || DEFAULT_BUTTON_TAG;
  const { payPaymentIntent, loading } = usePayPaymentIntent()

  const handleClick = React.useCallback(() => {
    if (!payPaymentIntent || !paymentIntent) return;
    return payPaymentIntent(paymentIntent);
  }, [paymentIntent, payPaymentIntent]);

  return (
    <Tag
      disabled={!paymentIntent || !payPaymentIntent || loading}
      className={className}
      onClick={handleClick}
      {...props}
    >
      {children}
    </Tag>
  );
}

export type { PayPaymentIntentButtonOwnProps };

export default PayPaymentIntentButton;
