import usePrism from "./usePrism";
import usePayPaymentIntent from "./usePayPaymentIntent";
import React from 'react';
import PrismContext from "../contexts/prism";

type PayInvoiceOptions = { prismAccount?: string }

export default function usePayInvoice(opts?: PayInvoiceOptions) {
  const prism = usePrism();
  const { prismAccount } = React.useContext(PrismContext);
  const [paymentIntentLoading, setPaymentIntentLoading] = React.useState(false);
  const { payPaymentIntent, loading, transaction } = usePayPaymentIntent(opts);

  const acc = React.useMemo(() => opts?.prismAccount || prismAccount, []);

  const payInvoice = React.useCallback(async (id: string) => {
    if (!prism || !payPaymentIntent) return;
    setPaymentIntentLoading(true);

    // TODO: Add pay route
    const paymentIntent = await prism.payInvoice(id, acc ? { prismAccount: acc } : undefined,);
    setPaymentIntentLoading(false);

    await payPaymentIntent(paymentIntent.id);

    return paymentIntent.id;
  }, [setPaymentIntentLoading, prism, payPaymentIntent])

  return {
    payInvoice: payPaymentIntent ? payInvoice : null,
    loading: loading || paymentIntentLoading,
    transaction
  };
}
