import usePrism from "./usePrism";
import React from 'react'
import PrismContext from '../contexts/prism';
import usePollPaymentIntent from "./usePollPaymentIntent";
import { useConnection, useWallet } from '@solana/wallet-adapter-react';
import { useSigner } from 'wagmi';

type PayPaymentIntentOptions = { prismAccount?: string }

export default function usePayPaymentIntent(opts?: PayPaymentIntentOptions) {
  const prism = usePrism();
  const { prismAccount } = React.useContext(PrismContext);
  const solWallet = useWallet();
  const { connection: solConnection } = useConnection()
  const pollPaymentIntent = usePollPaymentIntent();
  const { data: ethSigner } = useSigner()
  const [loading, setLoading] = React.useState(false);
  const [transaction, setTransaction] = React.useState('');

  const acc = React.useMemo(() => opts?.prismAccount || prismAccount, []);

  const payPaymentIntent = React.useCallback(async (id: string) => {
    if (!prism) return;
    setLoading(true);

    await prism.completePayment(
      id,
      { ethSigner, solWallet, solConnection },
      acc ? { prismAccount: acc } : undefined,
    )
      .then((res: any) => setTransaction(res.hash))
      .catch((err: Error) => {
        setLoading(false);
        throw err;
      });

    const completedPaymentIntent = await pollPaymentIntent(id);
    setLoading(false);

    return completedPaymentIntent;
  }, [prism, ethSigner, solWallet, solConnection, prismAccount, setLoading, setTransaction]);

  return {
    payPaymentIntent: (prism && ethSigner && solWallet && solConnection) ? payPaymentIntent : null,
    loading,
    transaction,
  }
}
